summaryrefslogtreecommitdiffstats
path: root/usr
diff options
context:
space:
mode:
authorBill Marquette <billm@pfsense.org>2007-10-17 00:25:25 +0000
committerBill Marquette <billm@pfsense.org>2007-10-17 00:25:25 +0000
commit709cc6e0f29e0fa16fa872a00940d078dc039506 (patch)
tree67ae43965365032a76026ad8e9c3f90069938f4a /usr
parent3702685f11cc41455faa75e995b02007f835480d (diff)
downloadpfsense-709cc6e0f29e0fa16fa872a00940d078dc039506.zip
pfsense-709cc6e0f29e0fa16fa872a00940d078dc039506.tar.gz
global s/[wW]ebGUI/webConfigurator/ - brought up via ticket #1427
Diffstat (limited to 'usr')
-rw-r--r--usr/local/pkg/carp_settings.xml2
-rwxr-xr-xusr/local/www/index.php4
-rwxr-xr-xusr/local/www/interfaces_assign.php2
-rwxr-xr-xusr/local/www/interfaces_lan.php2
-rwxr-xr-xusr/local/www/license.php4
-rwxr-xr-xusr/local/www/system.php8
-rwxr-xr-xusr/local/www/system_advanced.php12
-rw-r--r--usr/local/www/wizards/setup_wizard.xml4
8 files changed, 19 insertions, 19 deletions
diff --git a/usr/local/pkg/carp_settings.xml b/usr/local/pkg/carp_settings.xml
index 704fb91..6505d83 100644
--- a/usr/local/pkg/carp_settings.xml
+++ b/usr/local/pkg/carp_settings.xml
@@ -160,7 +160,7 @@
<field>
<fielddescr>Remote System Password</fielddescr>
<fieldname>password</fieldname>
- <description>Enter the webGUI password of the system that you would like to synchronize with.</description>
+ <description>Enter the webConfigurator password of the system that you would like to synchronize with.</description>
<type>password</type>
<note>NOTE: You will not use the Synchronize to IP and password option on backup cluster members!</note>
</field>
diff --git a/usr/local/www/interfaces_assign.php b/usr/local/www/interfaces_assign.php
index dc591ac..0349f62 100755
--- a/usr/local/www/interfaces_assign.php
+++ b/usr/local/www/interfaces_assign.php
@@ -279,7 +279,7 @@ if(file_exists("/var/run/interface_mismatch_reboot_needed"))
<ul>
<li><span class="vexpl">change the IP address of your computer</span></li>
<li><span class="vexpl">renew its DHCP lease</span></li>
- <li><span class="vexpl">access the webGUI with the new IP address</span></li>
+ <li><span class="vexpl">access the webConfigurator with the new IP address</span></li>
</ul></td>
</tr>
</table>
diff --git a/usr/local/www/interfaces_lan.php b/usr/local/www/interfaces_lan.php
index fdcef86..85a8493 100755
--- a/usr/local/www/interfaces_lan.php
+++ b/usr/local/www/interfaces_lan.php
@@ -243,7 +243,7 @@ function enable_change(enable_over) {
<ul>
<li>change the IP address of your computer</li>
<li>renew its DHCP lease</li>
- <li>access the webGUI with the new IP address</li>
+ <li>access the webConfigurator with the new IP address</li>
<li>be sure to add <a href="firewall_rules.php">firewall rules</a> to permit traffic through the interface.</li>
<li>You also need firewall rules for an interface in bridged mode as the firewall acts as a filtering bridge.</li>
</ul>
diff --git a/usr/local/www/license.php b/usr/local/www/license.php
index e93e5d3..d38b332 100755
--- a/usr/local/www/license.php
+++ b/usr/local/www/license.php
@@ -63,7 +63,7 @@ include("head.inc");
<br>
Rob Whyte (<a href="mailto:rob@g-labs.com">rob@g-labs.com</a>)<br>
&nbsp;&nbsp;&nbsp;&nbsp;<em><font color="#666666">Idea/code bits
- for encrypted webGUI passwords; minimalized SNMP agent</font></em><br>
+ for encrypted webConfigurator passwords; minimalized SNMP agent</font></em><br>
<br>
Petr Verner (<a href="mailto:verner@ipps.cz">verner@ipps.cz</a>)<br>
&nbsp;&nbsp;&nbsp;&nbsp;<em><font color="#666666">Advanced outbound
@@ -76,7 +76,7 @@ include("head.inc");
Jim McBeath (<a href="mailto:monowall@j.jimmc.org">monowall@j.jimmc.org</a>)<br>
&nbsp;&nbsp;&nbsp;&nbsp;<em><font color="#666666">Filter rule patches
(ordering, block/pass, disabled); better status page;<br>
- &nbsp;&nbsp;&nbsp;&nbsp;webGUI assign network ports page </font></em><br>
+ &nbsp;&nbsp;&nbsp;&nbsp;webConfigurator assign network ports page </font></em><br>
<br>
Chris Olive (<a href="mailto:chris@technologEase.com">chris@technologEase.com</a>)<br>
&nbsp;&nbsp;&nbsp;&nbsp;<em><font color="#666666">enhanced &quot;execute
diff --git a/usr/local/www/system.php b/usr/local/www/system.php
index da935f0..87461be 100755
--- a/usr/local/www/system.php
+++ b/usr/local/www/system.php
@@ -98,7 +98,7 @@ if ($_POST) {
}
if ($_POST['webguiport'] && (!is_numericint($_POST['webguiport']) ||
($_POST['webguiport'] < 1) || ($_POST['webguiport'] > 65535))) {
- $input_errors[] = "A valid TCP/IP port must be specified for the webGUI port.";
+ $input_errors[] = "A valid TCP/IP port must be specified for the webConfigurator port.";
}
if (($_POST['password']) && ($_POST['password'] != $_POST['password2'])) {
$input_errors[] = "The passwords do not match.";
@@ -224,16 +224,16 @@ include("head.inc");
PPTP VPN clients, though.</span></p></td>
</tr>
<tr>
- <td width="22%" valign="top" class="vncell">webGUI protocol</td>
+ <td width="22%" valign="top" class="vncell">webConfigurator protocol</td>
<td width="78%" class="vtable"> <input name="webguiproto" type="radio" value="http" <?php if ($pconfig['webguiproto'] == "http") echo "checked"; ?>>
HTTP &nbsp;&nbsp;&nbsp; <input type="radio" name="webguiproto" value="https" <?php if ($pconfig['webguiproto'] == "https") echo "checked"; ?>>
HTTPS</td>
</tr>
<tr>
- <td valign="top" class="vncell">webGUI port</td>
+ <td valign="top" class="vncell">webConfigurator port</td>
<td class="vtable"> <input name="webguiport" type="text" class="formfld unknown" id="webguiport" "size="5" value="<?=htmlspecialchars($config['system']['webgui']['port']);?>">
<br>
- <span class="vexpl">Enter a custom port number for the webGUI
+ <span class="vexpl">Enter a custom port number for the webConfigurator
above if you want to override the default (80 for HTTP, 443
for HTTPS). Changes will take effect immediately after save.</span></td>
</tr>
diff --git a/usr/local/www/system_advanced.php b/usr/local/www/system_advanced.php
index feab190..f4c9bd4 100755
--- a/usr/local/www/system_advanced.php
+++ b/usr/local/www/system_advanced.php
@@ -404,7 +404,7 @@ include("head.inc");
<td colspan="2" class="list" height="12">&nbsp;</td>
</tr>
<tr>
- <td colspan="2" valign="top" class="listtopic">webGUI SSL certificate/key</td>
+ <td colspan="2" valign="top" class="listtopic">webConfigurator SSL certificate/key</td>
</tr>
<tr>
<td width="22%" valign="top" class="vncell">Certificate</td>
@@ -470,7 +470,7 @@ include("head.inc");
<td width="78%" class="vtable">
<input name="polling_enable" type="checkbox" id="polling_enable" value="yes" <?php if ($pconfig['polling_enable']) echo "checked"; ?>>
<strong>Use device polling</strong><br>
- Device polling is a technique that lets the system periodically poll network devices for new data instead of relying on interrupts. This prevents your webGUI, SSH, etc. from being inaccessible due to interrupt floods when under extreme load. Generally this is not recommended.
+ Device polling is a technique that lets the system periodically poll network devices for new data instead of relying on interrupts. This prevents your webConfigurator, SSH, etc. from being inaccessible due to interrupt floods when under extreme load. Generally this is not recommended.
Not all NICs support polling; see the pfSense homepage for a list of supported cards.
</td>
</tr>
@@ -507,13 +507,13 @@ include("head.inc");
</tr>
<?php endif; ?>
<tr>
- <td width="22%" valign="top" class="vncell">webGUI anti-lockout</td>
+ <td width="22%" valign="top" class="vncell">webConfigurator anti-lockout</td>
<td width="78%" class="vtable">
<input name="noantilockout" type="checkbox" id="noantilockout" value="yes" <?php if ($pconfig['noantilockout']) echo "checked"; ?> />
- <strong>Disable webGUI anti-lockout rule</strong>
+ <strong>Disable webConfigurator anti-lockout rule</strong>
<br />
- By default, access to the webGUI on the LAN interface is always permitted, regardless of the user-defined filter
- rule set. Enable this feature to control webGUI access (make sure to have a filter rule in place that allows you
+ By default, access to the webConfigurator on the LAN interface is always permitted, regardless of the user-defined filter
+ rule set. Enable this feature to control webConfigurator access (make sure to have a filter rule in place that allows you
in, or you will lock yourself out!).
<br />
Hint: the &quot;set LAN IP address&quot; option in the console menu resets this setting as well.
diff --git a/usr/local/www/wizards/setup_wizard.xml b/usr/local/www/wizards/setup_wizard.xml
index fd37c28..9f63a7d 100644
--- a/usr/local/www/wizards/setup_wizard.xml
+++ b/usr/local/www/wizards/setup_wizard.xml
@@ -399,8 +399,8 @@
</step>
<step>
<id>6</id>
- <title>Set Admin WebGUI Password</title>
- <description>On this screen we will set the Admin password which is used to access the WebGUI and also SSH services if you wish to enable.</description>
+ <title>Set Admin webConfigurator Password</title>
+ <description>On this screen we will set the Admin password which is used to access the webConfigurator and also SSH services if you wish to enable.</description>
<fields>
<field>
<name>Admin Password</name>
OpenPOWER on IntegriCloud
diff --git a/usr/local/www/index.php b/usr/local/www/index.php
index c6d0985..51276cc 100755
--- a/usr/local/www/index.php
+++ b/usr/local/www/index.php
@@ -73,7 +73,7 @@
}
## If it is the first time webGUI has been
## accessed since initial install show this stuff.
if(file_exists('/conf/trigger_initial_wizard')) {
@@ -394,7 +394,7 @@ EOD;
$closehead = false;
## Set Page Title and Include Header
-$pgtitle = "pfSense webGUI";
+$pgtitle = "pfSense webConfigurator";
include("head.inc");
@@ -73,7 +73,7 @@
}
- ## If it is the first time webGUI has been
+ ## If it is the first time webConfigurator has been
## accessed since initial install show this stuff.
if(file_exists('/conf/trigger_initial_wizard')) {